Publish A Template Project — collective.templates documentation

# Publish A Template Project

Once the project owner has finished the edits in the form and save it, she / he could submit the template project for publication. This could be done within the menubar on the left side. She / he had to click on the menu entry ‘Private’ and than click on the entry ‘Submit for publication’ in the opening drop down menu. The menu entry will change from ‘Private’ to ‘Pending’.

The project owner will get an email with an information about this change of the workflow state. A corresponding email will be send to the administrator or a configured email address for this task (configured inside the ‘Template Center’.

The project has been forwarded into the review queue of the ‘Template Center’. Once the administrator, site-admiministrator or a reviewer changed the workflow state again, e.g. published the project, the project owner will get a further email with this new state.